@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,30 +14,27 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.cpp,v 1.4.2.1 2005/04/07 11:47:07 chpe Exp $
+ *  $Id: mozilla-helpers.cpp 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "mozilla-config.h"
-
 #include "config.h"
 
-#include "mozilla-helpers.h"
+#include <nsStringAPI.h>
 
 #include <gtkmozembed.h>
 #include <gtkmozembed_internal.h>
-
-#undef MOZILLA_INTERNAL_API
-#include <nsEmbedString.h>
-#define MOZILLA_INTERNAL_API 1
 #include <nsCOMPtr.h>
 #include <nsIChannel.h>
-#include <nsIHttpChannel.h>
 #include <nsIDOMDocument.h>
 #include <nsIDOMDocumentType.h>
 #include <nsIDOMNSDocument.h>
 #include <nsIDOMWindow.h>
+#include <nsIHttpChannel.h>
 #include <nsIWebBrowser.h>
 
+#include "mozilla-helpers.h"
+
 extern "C" char *
 mozilla_get_doctype (EphyEmbed *embed)
 {
@@ -59,11 +56,11 @@ mozilla_get_doctype (EphyEmbed *embed)
 	NS_ENSURE_TRUE (doctype, NULL);
 
 	nsresult rv;
-	nsEmbedString name;
+	nsString name;
 	rv = doctype->GetPublicId (name);
 	NS_ENSURE_SUCCESS (rv, NULL);
 
-	nsEmbedCString cName;
+	nsCString cName;
 	NS_UTF16ToCString (name, NS_CSTRING_ENCODING_UTF8, cName);
 
 	return g_strdup (cName.get());
@@ -89,10 +86,10 @@ mozilla_get_content_type (EphyEmbed *embed)
 	NS_ENSURE_TRUE (ns_doc, NULL);
 
 	nsresult rv;
-	nsEmbedString contentType;
+	nsString contentType;
 	rv = ns_doc->GetContentType (contentType);
 
-	nsEmbedCString cType;
+	nsCString cType;
 	NS_UTF16ToCString (contentType, NS_CSTRING_ENCODING_UTF8, cType);
 
 	return g_strdup (cType.get());
